@@ -1537,7 +1537,7 @@ def main() -> None:
         # dump file contents we know is terminal-safe
         if path in dump_content:
             with open(path, "rb") as fp:
-                print("uploading content: %r" % fp.read())
+                print("uploading content: %r" % bytes(fp.read()))
         assert args.output.endswith("/")
 
         # record history
